==> b3j0f.conf-0.1.2.zip: b3j0f.conf-0.1.2/b3j0f/conf/driver/file/core.py <==
# -*- coding: utf-8 -*-

# --------------------------------------------------------------------
# The MIT License (MIT)
#
# Copyright (c) 2014 Jonathan Labéjof <jonathan.labejof@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------

__all__ = ['FileConfDriver']


from stat import ST_SIZE

from os import stat

from os.path import exists, join

from sys import prefix

from b3j0f.conf.driver.core import ConfDriver


class FileConfDriver(ConfDriver):
    """Conf Manager dedicated to files.
    """

    CONF_DIR = join(prefix, 'etc')

    def exists(self, conf_path, *args, **kwargs):

        path = FileConfDriver.get_path(conf_path)

        result = exists(path) and stat(path)[ST_SIZE]

        return result

    @staticmethod
    def get_path(conf_path):

        result = join(FileConfDriver.CONF_DIR, conf_path)

        return result

==> b3j0f.conf-0.1.6.zip: b3j0f.conf-0.1.6/b3j0f/conf/driver/file/core.py <==
# -*- coding: utf-8 -*-

# --------------------------------------------------------------------
# The MIT License (MIT)
#
# Copyright (c) 2014 Jonathan Labéjof <jonathan.labejof@gmail.com>
#
# Permission is hereby granted, free of charge, to any person obtaining a copy
# of this software and associated documentation files (the "Software"), to deal
# in the Software without restriction, including without limitation the rights
# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
# copies of the Software, and to permit persons to whom the Software is
# furnished to do so, subject to the following conditions:
#
# The above copyright notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
# SOFTWARE.
# --------------------------------------------------------------------

__all__ = ['FileConfDriver']

"""This module specifies file drivers.

They work relatively to a conf directory which is given by the environment
variable ``B3J0F_CONF_DIR`` or if not present, by the relative path ``~/etc``.
"""

from stat import ST_SIZE

from os import stat, environ

from os.path import exists, join, expanduser

from b3j0f.conf.driver.core import ConfDriver


class FileConfDriver(ConfDriver):
    """Conf Manager dedicated to files.
    """

    CONF_DIR_VAR = 'B3J0F_CONF_DIR'  #: conf dir environment variable
    #: final conf dir, given by CONF_DIR_VAR environment variable or '~/etc'
    CONF_DIR = environ.get(
        CONF_DIR_VAR, join(expanduser('~'), 'etc')
    )

    def exists(self, conf_path, *args, **kwargs):

        path = FileConfDriver.get_path(conf_path)

        result = exists(path) and stat(path)[ST_SIZE]

        return result

    @staticmethod
    def get_path(conf_path):

        result = join(FileConfDriver.CONF_DIR, conf_path)

        return result
